/// <reference types="greasemonkey" />
/**
 * Encode binary data as isomorphic-encoded string.
 *
 * Binary data cannot be encoded as JavaScript string directly
 * because some binary data may contain some binary sequences
 * which are treated specially in the text encoding.
 * GM.xmlhttpRequest requires that each single byte (uint8) is encoded as CharCode.
 * By doing this, it is possible for GM.xmlHttpRequest to obtain the original binary data.
 *
 * https://developer.mozilla.org/en-US/docs/Web/API/btoa
 * https://infra.spec.whatwg.org/#isomorphic-encode
 * https://infra.spec.whatwg.org/#isomorphic-decode
 *
 * GreaseMonkey
 *   https://github.com/greasemonkey/greasemonkey/blob/efd22a93121225ada47f2fe9f021af0ab6100c21/src/bg/on-user-script-xhr.js#L140-L146
 */
export declare const encodeArrayBufferAsIsomorphicEncodedString: (b: ArrayBuffer) => string;
/**
 * Parse response headers string and covert it to Headers object.
 *
 * https://developer.mozilla.org/ja/docs/Web/API/XMLHttpRequest/getAllResponseHeaders
 */
export declare const parseXHRHeaders: (gmHeaders: string | null) => Headers;
/**
 * https://w3c.github.io/webappsec-subresource-integrity/#the-integrity-attribute
 */
export declare const verifyIntegrityWith: (crypto: Crypto) => (integrity: string, data: Blob) => Promise<void>;
export declare const verifyIntegrity: (integrity: string, data: Blob) => Promise<void>;
/**
 * Convert GM.Response to Response
 */
export declare const buildResponse: (res: GM.Response<any>) => Response;
/**
 * Supported status:
 *   init:
 *     - mode:           Ignored.
 *     - credentials:    Supported.
 *     - cache:          Ignored.
 *     - redirect:       Ignored. (if non-"follow" value is specified, error log will be printed.)
 *     - integrity:      Partially supported. Multiple integrities are not supported.
 *     - signal:         Supported.
 *     - referrer:       Ignored. TBD.
 *     - referrerPolicy: Ignored
 *   response object:
 *     - redirect: always false even if redirect.
 *     - type:     always "default"
 *
 * GreaseMonkey: https://wiki.greasespot.net/GM.xmlHttpRequest
 *   https://github.com/greasemonkey/greasemonkey/blob/efd22a93121225ada47f2fe9f021af0ab6100c21/src/bg/api-provider-source.js#L252
 *   https://github.com/greasemonkey/greasemonkey/blob/efd22a93121225ada47f2fe9f021af0ab6100c21/src/bg/on-user-script-xhr.js#L23
 *
 * Tampermonkey https://www.tampermonkey.net/documentation.php#GM_xmlhttpRequest
 *   NOTE: very old version of Tampermonkey
 *   https://github.com/Tampermonkey/tampermonkey/blob/07f668cd1cabb2939220045839dec4d95d2db0c8/src/xmlhttprequest.js
 *
 * Violentmonkey: https://violentmonkey.github.io/api/gm/#gm_xmlhttprequest
 *
 * Fetch Standard https://fetch.spec.whatwg.org/#fetch-method
 */
declare const gmFetch: (resource: RequestInfo, init?: RequestInit | undefined) => Promise<Response>;
export default gmFetch;
